@@ -7,7 +7,7 @@ import (
 	"path/filepath"
 	"strings"
 	"time"
-
+        goruntime "runtime"
 	"github.com/go-logr/logr"
 	mfc "github.com/manifestival/controller-runtime-client"
 	mf "github.com/manifestival/manifestival"
@@ -105,6 +105,10 @@ func fetchCommuntiyResources(mgr manager.Manager) (mf.Manifest, error) {
 	if flag.SkipNonRedHatResources {
 		return mf.Manifest{}, nil
 	}
+	if goruntime.GOARCH == "ppc64le" || goruntime.GOARCH == "s390x" {
+		log.Info("skip installation of tektoncd/catalog tasks as the platform is not x86_64")
+		return mf.Manifest{}, nil
+	}
 	//manifestival can take urls/filepaths as input
 	//more that one items can be passed as a comma separated list string
 	urls := strings.Join(flag.CommunityResourceURLs, ",")
@@ -123,7 +127,7 @@ func readAddons(mgr manager.Manager) (mf.Manifest, error) {
 	if err != nil {
 		return mf.Manifest{}, err
 	}
-
+	
 	// add optionals to addons if any
 	optionalResources, err := readOptional(mgr)
 	if err != nil {
